@@ -1,5 +1,5 @@
 # coding=UTF-8
-import json, math, os, urllib
+import json, math, os, urllib, urllib2
 
 from django.conf import settings
 from django.contrib.auth.models import User
@@ -7,7 +7,7 @@ from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.models import Site
 from django.core.mail import send_mail
 from django.db.models import Count
-from django.http import HttpResponse
+from django.http import HttpResponse, Http404
 from django.shortcuts import get_object_or_404, render_to_response
 from django.template import RequestContext
 from django.utils.html import strip_tags
@@ -17,64 +17,6 @@ from public_project.models import *
 from public_project.search import get_query, search_for_documents
 
 
-def check_config_prerequisits():
-    missing_cps = []
-    
-    if SiteConfig.objects.count() != 1:
-        missing_cps.append(_("Creation of (exactly) one SiteConfig object in the Django admin \
-with the general config params and non-dynamical contents."))
-    
-    if Project.objects.count() != 1:
-        missing_cps.append(_("Creation of (exactly) one Project object in the Django admin \
-with general information about the project."))
-    if ProjectGoalGroup.objects.count() == 0 or ProjectGoal.objects.count() == 0:
-        missing_cps.append(_("Creation of at least one ProjectGoalGroup object in the Django admin \
-containing at least one ProjectGoal."))
-        
-    context = {
-      'missing_cps': missing_cps,  
-    }
-    cp_met = len(missing_cps) == 0
-    return cp_met, render_to_response('config_prerequisits.html', context)
-
-
-def get_project():
-    return Project.objects.all()[0]
-
-
-def get_site_config(request):
-    site_config = SiteConfig.objects.all()[0]
-    
-    site_config.pdf_viewer = 'STANDARD'
-    site_config.browser = 'Unknown'
-    if 'HTTP_USER_AGENT' in request.META:
-        if 'Mozilla'.lower() in request.META['HTTP_USER_AGENT'].lower():
-            site_config.pdf_viewer = 'STANDARD'
-            site_config.browser = 'Mozilla'
-        if 'Safari'.lower() in request.META['HTTP_USER_AGENT'].lower():
-            site_config.pdf_viewer = 'STANDARD'
-            site_config.browser = 'Safari'
-        if 'Chrome'.lower() in request.META['HTTP_USER_AGENT'].lower():
-            site_config.pdf_viewer = 'STANDARD'
-            site_config.browser = 'Chrome'
-        if 'Opera'.lower() in request.META['HTTP_USER_AGENT'].lower():
-            site_config.pdf_viewer = 'STANDARD'
-            site_config.browser = 'Opera'
-        if 'MSIE'.lower() in request.META['HTTP_USER_AGENT'].lower():
-            if getattr(settings, 'DPP_IE_COMPATIBLE_PDF_VIEWER', False):
-                site_config.pdf_viewer = 'LEGACY'
-            else:
-                site_config.pdf_viewer = False
-            site_config.browser = 'MSIE'
-    
-    if getattr(settings, 'DPP_PUBLIC_API', False):
-        site_config.public_api = True
-    else:
-        site_config.public_api = False
-    
-    return site_config
-
-
 def get_research_request(request):
     if 'research_request_id' in request.GET:
         try:
@@ -228,10 +170,6 @@ def merge_with_search_tag_docs(document_list, object):
 
 
 def index(request):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
-    
     research_request_list = ResearchRequest.objects.all()
     comment_list = Comment.objects.filter(published=True)
     
@@ -245,15 +183,14 @@ def index(request):
         latest_document = None 
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
-        'category': 'home',
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': SiteCategory.objects.get_or_create(category='home')[0],
         'current_project_goal_group': ProjectGoalGroup.objects.get_current(),
         'project_part_list': ProjectPart.objects.all(),
         'latest_event': latest_event,
         'latest_document': latest_document,
         'activity_list': ActivityLog.objects.all()[0:5],
-        'research_request_list': research_request_list[0:1],
+        'research_request_list': research_request_list[0:3],
         'num_total_research_requests': len(research_request_list),
         'comment_list': comment_list[0:1],
         'num_total_comments': len(comment_list),
@@ -261,44 +198,38 @@ def index(request):
     return render_to_response('index.html', context)
 
 
-def project(request):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
+def project_parts(request):
+    site_category = SiteCategory.objects.get_or_create(category='project_parts')[0]
+    
+    main_project_parts = ProjectPart.objects.annotate(count=Count('main_project_parts')).filter(count=0)
+    middle = int(math.ceil(float(len(main_project_parts))/float(2)))
     
-    project_part_list = ProjectPart.objects.all()
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
-        'category': 'project',
-        'project_goal_group_list': ProjectGoalGroup.objects.all().order_by('event'),
-        'project_part_list': project_part_list,
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': site_category,
+        'main_project_part_list_left': main_project_parts[0:middle],
+        'main_project_part_list_right': main_project_parts[middle:],
     })
-    return render_to_response('project.html', context)
+    return render_to_response('project_parts.html', context)
 
 
 def project_part(request, project_part_id):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
-    
     project_part = get_object_or_404(ProjectPart, pk=project_part_id)
     
-    document_list = list(project_part.related_documents.order_by("title"))
-    document_list = merge_with_search_tag_docs(document_list, project_part)
-    
     comment_form_status = validate_comment_form(request)
     
     content_type = ContentType.objects.get(app_label="public_project", model="projectpart")
     comment_list = Comment.objects.filter(commentrelation__content_type=content_type).filter(commentrelation__object_id=project_part.id).filter(published=True).distinct()
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': SiteCategory.objects.get_or_create(category='project_parts')[0],
         'user_comment': get_user_comment(request),
-        'category': 'project',
         'project_part': project_part,
-        'document_list': document_list,
+        'question_list': project_part.get_questions(),
+        'event_list': project_part.get_events(),
+        'document_list': project_part.get_documents(),
+        'content_document_list': merge_with_search_tag_docs([], project_part),
         'comment_form_status': comment_form_status,
         'comment_list': comment_list[0:3],
         'num_total_comments': len(comment_list),
@@ -306,66 +237,40 @@ def project_part(request, project_part_id):
     return render_to_response('project_part.html', context)
 
 
-def process(request):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
+def goals(request):
+    
+    all_main_project_parts = ProjectPart.objects.annotate(count=Count('main_project_parts')).filter(count=0)
+    main_project_parts = []
+    for main_pp in all_main_project_parts:
+        if main_pp.projectgoalgroup_set.count() > 0:
+            main_project_parts.append(main_pp)
+    middle = int(math.ceil(float(len(main_project_parts))/float(2)))
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
-        'category': 'process',
-        'project_goal_group_list': ProjectGoalGroup.objects.all().order_by('event'),
-        'chronology_list': Event.objects.all(),
-        'latest_event_list': Event.objects.all()[0:5],
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': SiteCategory.objects.get_or_create(category='goals')[0],
+        'common_goal_group_list': ProjectGoalGroup.objects.filter(project_part=None).order_by('event'),
+        'main_project_part_list_left': main_project_parts[0:middle],
+        'main_project_part_list_right': main_project_parts[middle:],
     })
-    return render_to_response('process.html', context)
-
-
-def event(request, event_id):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
-    
-    event = get_object_or_404(Event, pk=event_id)
-    
-    document_list = list(event.related_documents.order_by("title"))
-    document_list = merge_with_search_tag_docs(document_list, event)
-    
-    comment_form_status = validate_comment_form(request)
-    content_type = ContentType.objects.get(app_label="public_project", model="event")
-    comment_list = Comment.objects.filter(commentrelation__content_type=content_type).filter(commentrelation__object_id=event.id).filter(published=True).distinct()
-    
-    context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
-        'user_comment': get_user_comment(request),
-        'category': 'process',
-        'event': event,
-        'document_list': document_list,
-        'comment_form_status': comment_form_status,
-        'comment_list': comment_list[0:3],
-        'num_total_comments': len(comment_list),
-    })
-    return render_to_response('event.html', context)
+    return render_to_response('goals.html', context)
 
 
 def questions(request):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
-    
-    project_parts = ProjectPart.objects.all()
-    middle = int(math.ceil(float(len(project_parts))/float(2)))
+    all_mpps = ProjectPart.objects.annotate(count=Count('main_project_parts')).filter(count=0)
+    main_project_parts = []
+    for mpp in all_mpps:
+        if mpp.get_num_questions() > 0:
+            main_project_parts.append(mpp)
+    middle = int(math.ceil(float(len(main_project_parts))/float(2)))
     
     research_request_list = ResearchRequest.objects.all()
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
-        'category': 'questions',
-        'project_part_list_left': project_parts[0:middle],
-        'project_part_list_right': project_parts[middle:],
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': SiteCategory.objects.get_or_create(category='questions')[0],
+        'main_project_part_list_left': main_project_parts[0:middle],
+        'main_project_part_list_right': main_project_parts[middle:],
         'research_request_list': research_request_list[0:3],
         'num_total_research_requests': len(research_request_list),
     })
@@ -373,10 +278,6 @@ def questions(request):
 
 
 def question(request, question_id):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
-    
     question = get_object_or_404(Question, pk=question_id)
     
     research_request_form_status = validate_research_request_form(request)
@@ -388,12 +289,12 @@ def question(request, question_id):
     comment_list = Comment.objects.filter(commentrelation__content_type=content_type).filter(commentrelation__object_id=question.id).filter(published=True).distinct()
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': SiteCategory.objects.get_or_create(category='questions')[0],
         'user_comment': get_user_comment(request),
         'research_request': get_research_request(request),
-        'category': 'question',
         'question': question,
+        'document_list': question.documents.all(),
         'research_request_form_status': research_request_form_status,
         'research_request_list': research_request_list[0:3],
         'num_total_research_requests': len(research_request_list),
@@ -405,45 +306,39 @@ def question(request, question_id):
 
 
 def participants(request):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
+    site_category = SiteCategory.objects.get_or_create(category='participants')[0]
+    participant_types = ParticipantType.objects.all()
+    middle = int(math.ceil(float(len(participant_types))/float(2)))
+    #groups = Participant.objects.annotate(count=Count('belongs_to')).filter(count=0)
+    #middle = int(math.ceil(float(len(groups))/float(2)))
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
-        'category': 'participants',
-        'ad_participant_list': Participant.objects.filter(participant_type='AD'),
-        'po_participant_list': Participant.objects.filter(participant_type='PO'),
-        'ci_participant_list': Participant.objects.filter(participant_type='CI'),
-        'co_participant_list': Participant.objects.filter(participant_type='CO'),
-        'se_participant_list': Participant.objects.filter(participant_type='SE'),
-        'latest_participant_list': Participant.objects.all().order_by('-date_added')[0:3],
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': site_category,
+        'participant_type_list_left': participant_types[0:middle],
+        'participant_type_list_right': participant_types[middle:],
+        #'group_list_left': groups[0:middle],
+        #'group_list_right': groups[middle:],
     })
     return render_to_response('participants.html', context)
 
 
 def participant(request, participant_id):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
-    
     participant = get_object_or_404(Participant, pk=participant_id)
     
-    document_list = list(participant.related_documents.order_by("title"))
-    document_list = merge_with_search_tag_docs(document_list, participant)
-    
     comment_form_status = validate_comment_form(request)
     content_type = ContentType.objects.get(app_label="public_project", model="participant")
     comment_list = Comment.objects.filter(commentrelation__content_type=content_type).filter(commentrelation__object_id=participant.id).filter(published=True).distinct()
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': SiteCategory.objects.get_or_create(category='participants')[0],
         'user_comment': get_user_comment(request),
-        'category': 'participants',
         'participant': participant,
-        'document_list': document_list,
+        'question_list': participant.get_questions(),
+        'event_list': participant.get_events(),
+        'document_list': participant.get_documents(),
+        'content_document_list': merge_with_search_tag_docs([], participant),
         'comment_form_status': comment_form_status,
         'comment_list': comment_list[0:3],
         'num_total_comments': len(comment_list),
@@ -451,21 +346,87 @@ def participant(request, participant_id):
     return render_to_response('participant.html', context)
 
 
-def documents(request):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
+def events(request):
+    site_category = SiteCategory.objects.get_or_create(category='events')[0]
     
-    project_parts = ProjectPart.objects.all()
-    middle = int(math.ceil(float(len(project_parts))/float(2)))
+    all_mpps = ProjectPart.objects.annotate(count=Count('main_project_parts')).filter(count=0)
+    main_project_parts = []
+    for mpp in all_mpps:
+        if mpp.get_num_events() > 0:
+            main_project_parts.append(mpp)
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
-        'category': 'documents',
-        'project_part_list_left': project_parts[0:middle],
-        'project_part_list_right': project_parts[middle:],
-        'latest_document_list': Document.objects.all()[0:3],
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': SiteCategory.objects.get_or_create(category='events')[0],
+        'project_goal_group_list': ProjectGoalGroup.objects.all().order_by('event'),
+        'chronology_list': Event.objects.all(),
+        'main_project_part_list': main_project_parts,
+    })
+    return render_to_response('events.html', context)
+
+
+def event(request, event_id):
+    event = get_object_or_404(Event, pk=event_id)
+    
+    content_document_list = merge_with_search_tag_docs([], event)
+    
+    comment_form_status = validate_comment_form(request)
+    content_type = ContentType.objects.get(app_label="public_project", model="event")
+    comment_list = Comment.objects.filter(commentrelation__content_type=content_type).filter(commentrelation__object_id=event.id).filter(published=True).distinct()
+    
+    context = RequestContext(request, {
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': SiteCategory.objects.get_or_create(category='events')[0],
+        'user_comment': get_user_comment(request),
+        'event': event,
+        'document_list': event.related_documents.order_by("title"),
+        'content_document_list': content_document_list,
+        'comment_form_status': comment_form_status,
+        'comment_list': comment_list[0:3],
+        'num_total_comments': len(comment_list),
+    })
+    return render_to_response('event.html', context)
+
+
+def web_source(request, web_source_id):
+    web_source = get_object_or_404(WebSource, pk=web_source_id)
+    
+    req = urllib2.Request(web_source.url, headers={'User-Agent' : "Magic Browser"}) 
+    response = urllib2.urlopen(req)
+    html = response.read()
+    
+    search_tags = SearchTag.objects.all()
+    found_search_tag_list = []
+    for st in search_tags:
+        if st.name.lower() in unicode(html, errors='replace').lower():
+            found_search_tag_list.append(st)
+    
+    context = RequestContext(request, {
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'web_source': web_source,
+        'found_search_tag_list': found_search_tag_list,
+    })
+    if request.user.is_authenticated():
+        return render_to_response('web_source.html', context)
+    else:
+        raise Http404
+
+
+def documents(request):
+    site_category = SiteCategory.objects.get_or_create(category='documents')[0]
+    
+    all_mpps = ProjectPart.objects.annotate(count=Count('main_project_parts')).filter(count=0)
+    main_project_parts = []
+    for mpp in all_mpps:
+        if mpp.get_num_documents() > 0:
+            main_project_parts.append(mpp)
+    middle = int(math.ceil(float(len(main_project_parts))/float(2)))
+    
+    context = RequestContext(request, {
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': site_category,
+        'main_project_part_list_left': main_project_parts[0:middle],
+        'main_project_part_list_right': main_project_parts[middle:],
     })
     return render_to_response('documents.html', context)
 
@@ -473,38 +434,55 @@ def documents(request):
 def xhr_universal_search(request):
     if request.method == 'GET' and 'query' in request.GET:
         query_string = request.GET['query']
+        query_string = unicode(query_string).encode('utf-8')
         
-        entry_query = get_query(query_string, ['name',])
-        pp_list = list(ProjectPart.objects.select_related().filter(entry_query)[0:10])
-        
-        entry_query = get_query(query_string, ['title',])
-        q_list = list(Question.objects.select_related().filter(entry_query)[0:10])
-        
-        entry_query = get_query(query_string, ['name',])
-        p_list = list(Participant.objects.select_related().filter(entry_query)[0:10])
-        
-        entry_query = get_query(query_string, ['title',])
-        e_list = list(Event.objects.select_related().filter(entry_query)[0:10])
-        
-        entry_query = get_query(query_string, ['title',])
-        d_list = list(Document.objects.select_related().filter(entry_query)[0:10])
-        
-        object_list = pp_list + q_list + p_list + e_list + d_list
+        if len(query_string) >= 4:
+            entry_query = get_query(query_string, ['name',])
+            p_list = list(Participant.objects.select_related().filter(entry_query)[0:10])
+            
+            entry_query = get_query(query_string, ['name',])
+            pp_list = list(ProjectPart.objects.select_related().filter(entry_query)[0:10])
+            
+            entry_query = get_query(query_string, ['title',])
+            q_list = list(Question.objects.select_related().filter(entry_query)[0:10])
+            
+            entry_query = get_query(query_string, ['title',])
+            e_list = list(Event.objects.select_related().filter(entry_query)[0:10])
+            
+            entry_query = get_query(query_string, ['title',])
+            d_list = list(Document.objects.select_related().filter(entry_query)[0:10])
+            
+            object_list = p_list + pp_list + q_list + e_list + d_list
+        else:
+            object_list = []
         
         res = {
             'values': {},
             'options': [],
         }
+        print query_string
+        if 'with_query_search' in request.GET:
+            if len(query_string) < 4:
+                option = query_string
+            else:
+                option = '<i class="icon-search"></i> ' + query_string
+            res['values'][option] = {
+                'content_type': 'query_search',
+                'id': 0,
+                'absolute_url': '/' + _('search_url') + '?q=' + urllib.quote_plus(query_string),
+            }
+            res['options'].append(option)
         
         for object in object_list:
             content_type = object.__class__.__name__.lower()
             id = object.id
             
-            if not (content_type == request.GET['ommit_content_type'] and str(id) == request.GET['ommit_id']):
+            if not 'ommit_content_type' in request.GET or not (content_type == request.GET['ommit_content_type'] and str(id) == request.GET['ommit_id']):
                 option = '<i class="' + object.get_icon_class() + '"></i> ' + unicode(object)
                 res['values'][option] = {
                     'content_type': content_type,
                     'id': id,
+                    'absolute_url': object.get_absolute_url(),
                 }
                 res['options'].append(option)
         
@@ -523,35 +501,30 @@ def xhr_document_tags(request):
         if request.POST['document_id']:
             document = get_object_or_404(Document, pk=request.POST['document_id'])
             if request.POST['content_type']:
-                cache_entries = SearchTagCacheEntry.objects.filter(document=document).filter(tag__content_type__model=request.POST['content_type'])
+                st_dict_list = SearchTagCacheEntry.objects.filter(document=document).filter(tag__content_type__model=request.POST['content_type']).values('tag__name', 'tag__content_type__model',).annotate(num_tags=Count('tag__name')).order_by('-num_tags')
+                #cache_entries = SearchTagCacheEntry.objects.filter(document=document).filter(tag__content_type__model=request.POST['content_type'])
             else:
-                cache_entries = SearchTagCacheEntry.objects.filter(document=document)
-            cache_entries = cache_entries[0:16]
-            size_start = 14
+                st_dict_list = SearchTagCacheEntry.objects.filter(document=document).values('tag__name', 'tag__content_type__model',).annotate(num_tags=Count('tag__name')).order_by('-num_tags')
+            st_dict_list = st_dict_list[0:16]
+            size_start = 10
             size_span = 10
         else:
-            cache_entries = []
             if request.POST['content_type']:
-                search_tags = SearchTag.objects.filter(content_type__model=request.POST['content_type']).annotate(num_cache_entries=Count('searchtagcacheentry')).order_by('-num_cache_entries')[0:22]
+                st_dict_list = SearchTagCacheEntry.objects.filter(tag__content_type__model=request.POST['content_type']).values('tag__name', 'tag__content_type__model',).annotate(num_tags=Count('tag__name')).order_by('-num_tags')[0:22]
             else:
-                search_tags = SearchTag.objects.annotate(num_cache_entries=Count('searchtagcacheentry')).order_by('-num_cache_entries')[0:22]
-            for st in search_tags:
-                if(st.searchtagcacheentry_set.count() > 0):
-                    ce = st.searchtagcacheentry_set.all()[0]
-                    ce.num_results = st.searchtagcacheentry_set.count()
-                    cache_entries.append(ce)
-            size_start = 16
+                st_dict_list = SearchTagCacheEntry.objects.values('tag__name', 'tag__content_type__model',).annotate(num_tags=Count('tag__name')).order_by('-num_tags')[0:22]
+            size_start = 12
             size_span = 12
         
-        if len(cache_entries) > 0:
-            first = cache_entries[0]
-            max_num_results = first.num_results
+        if len(st_dict_list) > 0:
+            first = st_dict_list[0]
+            max_num_results = first['num_tags']
         
         words = []
-        for ce in cache_entries:
-            text = ce.tag.name
-            size = size_start + int(round((float(ce.num_results)/ float(max_num_results)) * size_span))
-            color = colors[ce.tag.content_type.model]
+        for st_dict in st_dict_list:
+            text = st_dict['tag__name']
+            size = size_start + int(round((float(st_dict['num_tags'])/ float(max_num_results)) * size_span))
+            color = colors[st_dict['tag__content_type__model']]
             
             word = { "text": text, "size":size, "color": color, }
             words.append(word)
@@ -563,11 +536,6 @@ def xhr_document_tags(request):
 
 
 def document(request, document_id):
-    
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
-    
     document = get_object_or_404(Document, pk=document_id)
     comment_form_status = validate_comment_form(request)
     
@@ -590,10 +558,9 @@ def document(request, document_id):
     comment_list.sort(key=lambda x:x.page)
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
+        'site_config': SiteConfig.objects.get_site_config(request),
+        'site_category': SiteCategory.objects.get_or_create(category='documents')[0],
         'user_comment': get_user_comment(request),
-        'category': 'documents',
         'document': document,
         'found_pages': found_pages,
         'comment_form_status': comment_form_status,
@@ -625,9 +592,7 @@ def search(request):
         document_list = search_for_documents(query_string)
         
         context = RequestContext(request, {
-            'site_config': get_site_config(request),
-            'project': get_project(),
-            'category': 'search',
+            'site_config': SiteConfig.objects.get_site_config(request),
             'query': query_string,
             'project_part_list': project_part_list,
             'question_list': question_list,
@@ -656,8 +621,7 @@ def research_requests(request, object_id, content_type):
     ph_title = unicode(object)
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
+        'site_config': SiteConfig.objects.get_site_config(request),
         'rr_object': object,
         'research_request_list': research_request_list,
         'num_total_research_requests': len(research_request_list),
@@ -698,8 +662,7 @@ def comments(request, object_id, content_type):
     ph_title = unicode(object)
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
+        'site_config': SiteConfig.objects.get_site_config(request),
         'commented_object': object,
         'comment_list': comment_list,
         'num_total_comments': len(comment_list),
@@ -711,27 +674,17 @@ def comments(request, object_id, content_type):
 
 
 def api(request):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
-    
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
+        'site_config': SiteConfig.objects.get_site_config(request),
     })
     return render_to_response('api.html', context)
 
 
 def contact(request):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
-    
     image_list = Image.objects.all()
     
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
+        'site_config': SiteConfig.objects.get_site_config(request),
         'image_list': image_list,
     })
     return render_to_response('contact.html', context)
@@ -739,7 +692,7 @@ def contact(request):
 
 def activate_comment(request):
     c = get_object_or_404(Comment, activation_hash=request.GET['activation_hash'])
-    site_config = get_site_config(request)
+    site_config = SiteConfig.objects.get_site_config(request)
     
     res  = '<!DOCTYPE html><html><head><meta charset="utf-8"></head><body>'
     res += '<div style="margin:20px;padding:20px;border:1px solid #999;float:left;color:#333;font-size:14px;'
@@ -788,13 +741,8 @@ def activate_comment(request):
 
 
 def custom_404_view(request):
-    cp, response = check_config_prerequisits()
-    if not cp:
-        return response
-    
     context = RequestContext(request, {
-        'site_config': get_site_config(request),
-        'project': get_project(),
+        'site_config': SiteConfig.objects.get_site_config(request),
     })
     return render_to_response('404.html', context)
     
